pub struct ExternalMethod {
pub fn_ptr: usize,
pub input_layout: Struct,
pub output_layout: Layout,
}Expand description
A declaration of an external method. Gives a raw function pointer to be called in jyafn code accompanied by the layout of the input and the output of the function.
Fields
fn_ptr: usizeThe function pointer to be called in jyafn code.
input_layout: StructThe input layout of the given function.
output_layout: LayoutOutput layout of the given function.