pub type ExtensionInit = unsafe extern "C" fn() -> *const c_char;Expand description
The initialization function for the extension. This function should return a JSON
enconded ExtensionManifest or a null pointer in case of an error.
pub type ExtensionInit = unsafe extern "C" fn() -> *const c_char;The initialization function for the extension. This function should return a JSON
enconded ExtensionManifest or a null pointer in case of an error.