Visitor

Struct Visitor 

pub struct Visitor(/* private fields */);
A builder of binary data to be sent to and from functions. This represents a sequence of slots of 64-bit data that can be grown by pushing more 64-bid data into it.

Implementations

Source

impl Visitor

pub fn new(size: Size) -> Visitor

pub fn into_inner(self) -> Box<[u8]>

pub fn reset(&mut self)

pub fn set_full(&mut self)

pub fn buffer(&self) -> &[u8]

pub fn buffer_mut(&mut self) -> &mut [u8]

pub fn push(&mut self, val: f64)

Pushes a new scalar value into the visitor.

pub fn pop(&mut self) -> f64

Removes a scalar value from the end of the visitor, shrinking it by 1 slot.

pub fn push_int(&mut self, val: i64)

Pushes a new integer value into the visitor.

pub fn pop_int(&mut self) -> i64

Removes an integer value from the end of the visitor, shrinking it by 1 slot.

pub fn push_uint(&mut self, val: u64)

Pushes a new unsigned integer value into the visitor.

pub fn pop_uint(&mut self) -> u64

Removes an integer value from the end of the visitor, shrinking it by 1 slot.