#[repr(transparent)]pub struct RawResourceMethod(pub unsafe extern "C" fn(*const (), *const u8, u64, *mut u8, u64) -> *mut u8);Expand description
The signature of the function that will be invoked from inside the function code.
Tuple Fields
0: unsafe extern "C" fn(*const (), *const u8, u64, *mut u8, u64) -> *mut u8Trait Implementations
Sourceimpl Clone for RawResourceMethod
impl Clone for RawResourceMethod
Sourcefn clone(&self) -> RawResourceMethod
fn clone(&self) -> RawResourceMethod
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RawResourceMethod
impl Debug for RawResourceMethod
Sourceimpl GetSize for RawResourceMethod
impl GetSize for RawResourceMethod
Sourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourceimpl Ord for RawResourceMethod
impl Ord for RawResourceMethod
Sourcefn cmp(&self, other: &RawResourceMethod) -> Ordering
fn cmp(&self, other: &RawResourceMethod) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RawResourceMethod
impl PartialEq for RawResourceMethod
Sourceimpl PartialOrd for RawResourceMethod
impl PartialOrd for RawResourceMethod
impl Copy for RawResourceMethod
impl Eq for RawResourceMethod
impl StructuralPartialEq for RawResourceMethod