pub struct StringSymbols {
pub fn_drop: unsafe extern "C" fn(*mut c_char),
}Expand description
Lists the name of the symbols needed to create the interface between C-style strings from the extension and jyafn.
Fields
fn_drop: unsafe extern "C" fn(*mut c_char)Drops any allocated memory created for the C-style string pointed by the input. This will be called only on pointers generated from within the extension (returned strings) and will be called only once per pointer.