pub struct Visitor(/* private fields */);Expand description
A builder of binary data to be sent to and from functions. This represents a sequence of slots of 64-bit data that can be grown by pushing more 64-bid data into it.
Implementations
Sourceimpl Visitor
impl Visitor
pub fn new(size: Size) -> Visitor
pub fn into_inner(self) -> Box<[u8]>
pub fn reset(&mut self)
pub fn set_full(&mut self)
pub fn buffer(&self) -> &[u8] ⓘ
pub fn buffer_mut(&mut self) -> &mut [u8] ⓘ
Sourcepub fn pop(&mut self) -> f64
pub fn pop(&mut self) -> f64
Removes a scalar value from the end of the visitor, shrinking it by 1 slot.